
if (CMAKE_VERSION VERSION_LESS 3.1.0)
    message(FATAL_ERROR "Qt 5 WebChannel module requires at least CMake version 3.1.0")
endif()

# redirect to static package overriding variant prefix so it does not contain Static anymore
option(USE_STATIC_QT_BY_DEFAULT "specifies whether to use static Qt by default (rather than via Static-prefix)" OFF)
if(USE_STATIC_QT_BY_DEFAULT)
    set(ORIGINAL_OVERRIDE_QT_VARIANT_PREFIX ${OVERRIDE_QT_VARIANT_PREFIX})
    if(OVERRIDE_QT_VARIANT_PREFIX)
        string(REPLACE "Static" "" OVERRIDE_QT_VARIANT_PREFIX ${OVERRIDE_QT_VARIANT_PREFIX})
    endif()
    if(NOT OVERRIDE_QT_VARIANT_PREFIX)
        set(OVERRIDE_QT_VARIANT_PREFIX none)
    endif()
    find_package(StaticQt5WebChannel)
    set(OVERRIDE_QT_VARIANT_PREFIX ${ORIGINAL_OVERRIDE_QT_VARIANT_PREFIX})
    return()
endif()

if(OVERRIDE_QT_VARIANT_PREFIX)
    if(OVERRIDE_QT_VARIANT_PREFIX STREQUAL none)
        unset(QT_VARIANT_PREFIX)
    else()
        set(QT_VARIANT_PREFIX ${OVERRIDE_QT_VARIANT_PREFIX})
    endif()
else()
    set(QT_VARIANT_PREFIX "")
endif()

get_filename_component(_qt5WebChannel_install_prefix "${CMAKE_CURRENT_LIST_DIR}/../../../" ABSOLUTE)

# For backwards compatibility only. Use Qt5WebChannel_VERSION instead.
set(${QT_VARIANT_PREFIX}Qt5WebChannel_VERSION_STRING 5.12.1)

set(${QT_VARIANT_PREFIX}Qt5WebChannel_LIBRARIES ${QT_VARIANT_PREFIX}Qt5::WebChannel)

macro(_qt5_WebChannel_check_file_exists FILE)
    if(NOT EXISTS "${FILE}")
        message(FATAL_ERROR "The imported target \"${QT_VARIANT_PREFIX}Qt5::WebChannel\" references the file
   \"${FILE}\"
but this file does not exist.  Possible reasons include:
* The file was deleted, renamed, or moved to another location.
* An install or uninstall procedure did not complete successfully.
* The installation package was faulty and contained
   \"${CMAKE_CURRENT_LIST_FILE}\"
but not all the files it references.
")
    endif()
endmacro()


macro(_populate_WebChannel_target_properties TARGET_NAME TARGET_CONFIG LIB_LOCATION IMPLIB_LOCATION)
    set_property(TARGET ${TARGET_NAME} APPEND PROPERTY IMPORTED_CONFIGURATIONS ${TARGET_CONFIG})


    set(imported_location "${_qt5WebChannel_install_prefix}/bin/${LIB_LOCATION}")


    _qt5_WebChannel_check_file_exists(${imported_location})

    set_target_properties(${TARGET_NAME} PROPERTIES
        "INTERFACE_LINK_LIBRARIES_${TARGET_CONFIG}" "${_Qt5WebChannel_LIB_DEPENDENCIES}"
        "IMPORTED_LOCATION_${TARGET_CONFIG}" ${imported_location}
        # For backward compatibility with CMake < 2.8.12
        "IMPORTED_LINK_INTERFACE_LIBRARIES_${TARGET_CONFIG}" "${_Qt5WebChannel_LIB_DEPENDENCIES}"
    )

    set(imported_implib "${_qt5WebChannel_install_prefix}/lib/${IMPLIB_LOCATION}")
    _qt5_WebChannel_check_file_exists(${imported_implib})
    if(NOT "${IMPLIB_LOCATION}" STREQUAL "")
        set_target_properties(${QT_VARIANT_PREFIX}Qt5::WebChannel PROPERTIES
        "IMPORTED_IMPLIB_${TARGET_CONFIG}" ${imported_implib}
        )
    endif()
endmacro()

set(TARGET_NAME ${QT_VARIANT_PREFIX}Qt5::WebChannel)

if(NOT TARGET ${TARGET_NAME})
    set(_Qt5WebChannel_OWN_INCLUDE_DIRS "${_qt5WebChannel_install_prefix}/include/qt/" "${_qt5WebChannel_install_prefix}/include/qt/QtWebChannel")
    set(${QT_VARIANT_PREFIX}Qt5WebChannel_PRIVATE_INCLUDE_DIRS
        "${_qt5WebChannel_install_prefix}/include/qt/QtWebChannel/5.12.1"
        "${_qt5WebChannel_install_prefix}/include/qt/QtWebChannel/5.12.1/QtWebChannel"
    )
    include("${CMAKE_CURRENT_LIST_DIR}/ExtraSourceIncludes.cmake" OPTIONAL)

    foreach(_dir ${_Qt5WebChannel_OWN_INCLUDE_DIRS})
        _qt5_WebChannel_check_file_exists(${_dir})
    endforeach()

    # Only check existence of private includes if the Private component is
    # specified.
    list(FIND Qt5WebChannel_FIND_COMPONENTS Private _check_private)
    if (NOT _check_private STREQUAL -1)
        foreach(_dir ${Qt5WebChannel_PRIVATE_INCLUDE_DIRS})
            _qt5_WebChannel_check_file_exists(${_dir})
        endforeach()
    endif()

    set(${QT_VARIANT_PREFIX}Qt5WebChannel_INCLUDE_DIRS ${_Qt5WebChannel_OWN_INCLUDE_DIRS})

    set(${QT_VARIANT_PREFIX}Qt5WebChannel_DEFINITIONS -DQT_WEBCHANNEL_LIB)
    set(${QT_VARIANT_PREFIX}Qt5WebChannel_COMPILE_DEFINITIONS QT_WEBCHANNEL_LIB)
    set(_Qt5WebChannel_MODULE_DEPENDENCIES "Qml;Core")


    set(${QT_VARIANT_PREFIX}Qt5WebChannel_OWN_PRIVATE_INCLUDE_DIRS ${Qt5WebChannel_PRIVATE_INCLUDE_DIRS})

    set(_Qt5WebChannel_FIND_DEPENDENCIES_REQUIRED)
    if (${QT_VARIANT_PREFIX}Qt5WebChannel_FIND_REQUIRED)
        set(_Qt5WebChannel_FIND_DEPENDENCIES_REQUIRED REQUIRED)
    endif()
    set(_Qt5WebChannel_FIND_DEPENDENCIES_QUIET)
    if (Qt5WebChannel_FIND_QUIETLY)
        set(_Qt5WebChannel_DEPENDENCIES_FIND_QUIET QUIET)
    endif()
    set(_Qt5WebChannel_FIND_VERSION_EXACT)
    if (${QT_VARIANT_PREFIX}Qt5WebChannel_FIND_VERSION_EXACT)
        set(_Qt5WebChannel_FIND_VERSION_EXACT EXACT)
    endif()

    set(${QT_VARIANT_PREFIX}Qt5WebChannel_EXECUTABLE_COMPILE_FLAGS "")

    foreach(_module_dep ${_Qt5WebChannel_MODULE_DEPENDENCIES})
        if (NOT ${QT_VARIANT_PREFIX}Qt5${_module_dep}_FOUND)
            find_package(${QT_VARIANT_PREFIX}Qt5${_module_dep}
                5.12.1 ${_Qt5WebChannel_FIND_VERSION_EXACT}
                ${_Qt5WebChannel_DEPENDENCIES_FIND_QUIET}
                ${_Qt5WebChannel_FIND_DEPENDENCIES_REQUIRED}
                PATHS "${CMAKE_CURRENT_LIST_DIR}/.." NO_DEFAULT_PATH
            )
        endif()

        if (NOT ${QT_VARIANT_PREFIX}Qt5${_module_dep}_FOUND)
            set(${QT_VARIANT_PREFIX}Qt5WebChannel_FOUND False)
            return()
        endif()

        list(APPEND ${QT_VARIANT_PREFIX}Qt5WebChannel_INCLUDE_DIRS "${Qt5${_module_dep}_INCLUDE_DIRS}")
        list(APPEND ${QT_VARIANT_PREFIX}Qt5WebChannel_PRIVATE_INCLUDE_DIRS "${Qt5${_module_dep}_PRIVATE_INCLUDE_DIRS}")
        list(APPEND ${QT_VARIANT_PREFIX}Qt5WebChannel_DEFINITIONS ${Qt5${_module_dep}_DEFINITIONS})
        list(APPEND ${QT_VARIANT_PREFIX}Qt5WebChannel_COMPILE_DEFINITIONS ${Qt5${_module_dep}_COMPILE_DEFINITIONS})
        list(APPEND ${QT_VARIANT_PREFIX}Qt5WebChannel_EXECUTABLE_COMPILE_FLAGS ${Qt5${_module_dep}_EXECUTABLE_COMPILE_FLAGS})
    endforeach()
    list(REMOVE_DUPLICATES ${QT_VARIANT_PREFIX}Qt5WebChannel_INCLUDE_DIRS)
    list(REMOVE_DUPLICATES ${QT_VARIANT_PREFIX}Qt5WebChannel_PRIVATE_INCLUDE_DIRS)
    list(REMOVE_DUPLICATES ${QT_VARIANT_PREFIX}Qt5WebChannel_DEFINITIONS)
    list(REMOVE_DUPLICATES ${QT_VARIANT_PREFIX}Qt5WebChannel_COMPILE_DEFINITIONS)
    list(REMOVE_DUPLICATES ${QT_VARIANT_PREFIX}Qt5WebChannel_EXECUTABLE_COMPILE_FLAGS)

    set(_Qt5WebChannel_LIB_DEPENDENCIES "${QT_VARIANT_PREFIX}Qt5::Qml;${QT_VARIANT_PREFIX}Qt5::Core")


    add_library(${QT_VARIANT_PREFIX}Qt5::WebChannel SHARED IMPORTED)



    set_property(TARGET ${QT_VARIANT_PREFIX}Qt5::WebChannel PROPERTY
      INTERFACE_INCLUDE_DIRECTORIES ${_Qt5WebChannel_OWN_INCLUDE_DIRS})
    set_property(TARGET ${QT_VARIANT_PREFIX}Qt5::WebChannel PROPERTY
        INTERFACE_COMPILE_DEFINITIONS QT_WEBCHANNEL_LIB)

    set_property(TARGET ${QT_VARIANT_PREFIX}Qt5::WebChannel PROPERTY INTERFACE_QT_ENABLED_FEATURES )
    set_property(TARGET ${QT_VARIANT_PREFIX}Qt5::WebChannel PROPERTY INTERFACE_QT_DISABLED_FEATURES )

    # Find plugin targets
    file(GLOB pluginTargetsMaybe "${CMAKE_CURRENT_LIST_DIR}/*Qt5WebChannel_*.cmake")
    unset(pluginTargets)
    if(pluginTargetsMaybe)
        foreach(pluginTarget ${pluginTargetsMaybe})
            file(STRINGS ${pluginTarget} matched REGEX Qt5WebChannel_PLUGINS)
            if(matched)
                list(APPEND pluginTargets ${pluginTarget})
            endif()
        endforeach()
    endif()

    macro(_populate_WebChannel_plugin_properties TARGET_NAME PLUGIN_TARGET_NAME PLUGIN_NAME CONFIG PLUGIN_LOCATION)
        set_property(TARGET ${PLUGIN_TARGET_NAME} APPEND PROPERTY IMPORTED_CONFIGURATIONS ${CONFIG})

        set(imported_location "${_qt5WebChannel_install_prefix}/lib/qt/plugins/${PLUGIN_LOCATION}")
        _qt5_WebChannel_check_file_exists(${imported_location})
        set_target_properties(${PLUGIN_TARGET_NAME} PROPERTIES
            "IMPORTED_LOCATION_${CONFIG}" ${imported_location}
        )

    endmacro()

    if(pluginTargets)
        foreach(pluginTarget ${pluginTargets})
            include(${pluginTarget})
        endforeach()
    endif()

    set(_Qt5WebChannel_PRIVATE_DIRS_EXIST TRUE)
    foreach (_Qt5WebChannel_PRIVATE_DIR ${${QT_VARIANT_PREFIX}Qt5WebChannel_OWN_PRIVATE_INCLUDE_DIRS})
        if (NOT EXISTS ${_Qt5WebChannel_PRIVATE_DIR})
            set(_Qt5WebChannel_PRIVATE_DIRS_EXIST FALSE)
        endif()
    endforeach()

    if (_Qt5WebChannel_PRIVATE_DIRS_EXIST)
        add_library(${QT_VARIANT_PREFIX}Qt5::WebChannelPrivate INTERFACE IMPORTED)
        set_property(TARGET ${QT_VARIANT_PREFIX}Qt5::WebChannelPrivate PROPERTY
            INTERFACE_INCLUDE_DIRECTORIES ${${QT_VARIANT_PREFIX}Qt5WebChannel_OWN_PRIVATE_INCLUDE_DIRS}
        )
        set(_Qt5WebChannel_PRIVATEDEPS)
        foreach(dep ${_Qt5WebChannel_LIB_DEPENDENCIES})
            if (TARGET ${dep}Private)
                list(APPEND _Qt5WebChannel_PRIVATEDEPS ${dep}Private)
            endif()
        endforeach()
        set_property(TARGET ${QT_VARIANT_PREFIX}Qt5::WebChannelPrivate PROPERTY
            INTERFACE_LINK_LIBRARIES ${QT_VARIANT_PREFIX}Qt5::WebChannel ${_Qt5WebChannel_PRIVATEDEPS}
        )
    endif()

    _populate_WebChannel_target_properties(${QT_VARIANT_PREFIX}Qt5::WebChannel RELEASE "Qt5WebChannel.dll" "libQt5WebChannel.dll.a" )


    if (EXISTS
        "${_qt5WebChannel_install_prefix}/bin/Qt5WebChanneld.dll"
    AND EXISTS
        "${_qt5WebChannel_install_prefix}/lib/libQt5WebChanneld.dll.a" )
        _populate_WebChannel_target_properties(${QT_VARIANT_PREFIX}Qt5::WebChannel DEBUG "Qt5WebChanneld.dll" "libQt5WebChanneld.dll.a" )
    endif()



_qt5_WebChannel_check_file_exists("${CMAKE_CURRENT_LIST_DIR}/../${QT_VARIANT_PREFIX}Qt5WebChannel/${QT_VARIANT_PREFIX}Qt5WebChannelConfigVersion.cmake")

endif()
